@@ -46,3 +46,12 @@ test_that("qunif", {
   testit(1, 12)
   testit(-2, 1)
 })
+
+test_that("assigning integer value results in int", {
+
+  p = ParamSet$new(list(ParamInt$new("x")))
+  p$values$x = 0
+  expect_equal(typeof(p$values$x), "integer")
+  expect_error({p$values$x = 1e-10}, "Must be of type.*integerish")
+
+})
