@@ -99,6 +99,13 @@ test_that("requirements in domains", {
       y = p_dbl(depends = x == 1)
     ), simpleps)
 
+  # quote() is accepted
+  expect_equal(
+    ps(
+      x = p_int(),
+      y = p_dbl(depends = quote(x == 1))
+    ), simpleps)
+
   # using a expression variable
   reqquote = quote(x == 1)
   expect_equal(
@@ -238,3 +245,56 @@ test_that("trafos in domains", {
   })$trafo(list(x = 2, y = "gamma", z = 4)), list(x = exp(1), y = 2 * sqrt(3), z = 4, n = 1))
 
 })
+
+test_that("logscale in domains", {
+
+  expect_error(p_dbl(trafo = exp, logscale = TRUE), "When a trafo is given then logscale must be FALSE")
+  expect_error(p_int(trafo = exp, logscale = TRUE), "When a trafo is given then logscale must be FALSE")
+
+  expect_error(p_int(lower = 1, upper = 2.5, logscale = TRUE), "failed.*integer.*value.*not.*double")
+
+  expect_error(p_int(lower = -1, logscale = TRUE), "When logscale is TRUE then lower bound must be greater or equal 0")
+  expect_error(p_dbl(lower = 0, logscale = TRUE), "When logscale is TRUE then lower bound must be strictly greater than 0")
+  expect_error(p_int(logscale = TRUE), "When logscale is TRUE then lower bound must be greater or equal 0")
+  expect_error(p_dbl(logscale = TRUE), "When logscale is TRUE then lower bound must be strictly greater than 0")
+
+  p = ps(x = p_dbl(lower = 1, logscale = TRUE), y = p_int(lower = 1, logscale = TRUE))
+  expect_equal(p$lower, c(x = 0, y = 0))
+  expect_equal(p$upper, c(x = Inf, y = Inf))
+  expect_equal(p$trafo(list(x = 0, y = log(1.5))), list(x = 1, y = 1))
+  expect_equal(p$trafo(list(x = 0, y = log(0.001))), list(x = 1, y = 1))
+  expect_equal(p$trafo(list(x = log(10), y = log(20.5))), list(x = 10, y = 20))
+
+  p = ps(x = p_dbl(lower = 1, upper = 10, logscale = TRUE), y = p_int(lower = 0, upper = 10, logscale = TRUE))
+
+  expect_equal(p$lower, c(x = 0, y = log(.5)))
+  expect_equal(p$upper, c(x = log(10), y = log(11)))
+
+  expect_equal(p$trafo(list(x = 0, y = log(1.5))), list(x = 1, y = 1))
+  expect_equal(p$trafo(list(x = log(10), y = log(11))), list(x = 10, y = 10))
+
+  expect_equal(p$trafo(list(x = log(10), y = log(20))), list(x = 10, y = 10))
+  expect_equal(p$trafo(list(x = log(10), y = log(9.99))), list(x = 10, y = 9))
+
+  expect_equal(p$trafo(list(x = log(10), y = log(1.5))), list(x = 10, y = 1))
+
+  expect_equal(p$trafo(list(x = log(10), y = log(0.5))), list(x = 10, y = 0))
+
+  expect_equal(p$trafo(list(x = log(10), y = log(0.0001))), list(x = 10, y = 0))
+
+  expect_output(print(p_dbl(lower = 1, upper = 10, logscale = TRUE)), "^p_dbl\\(lower = 1, upper = 10, logscale = TRUE\\)$")
+  expect_output(print(p_dbl(lower = 1, logscale = TRUE)), "^p_dbl\\(lower = 1, logscale = TRUE\\)$")
+  expect_output(print(p_int(lower = 0, upper = 10, logscale = TRUE)), "^p_int\\(lower = 0, upper = 10, logscale = TRUE\\)$")
+  expect_output(print(p_int(lower = 0, logscale = TRUE)), "^p_int\\(lower = 0, logscale = TRUE\\)$")
+
+  expect_output(print(p_int(lower = 0, logscale = FALSE)), "^p_int\\(lower = 0, logscale = FALSE\\)$")
+
+  params = ps(x = p_dbl(1, 100, logscale = TRUE))
+  grid = generate_design_grid(params, 3)
+  expect_equal(grid$transpose(), list(list(x = 1), list(x = 10), list(x = 100)))
+
+  params = ps(x = p_int(0, 10, logscale = TRUE))
+  grid = generate_design_grid(params, 4)
+  expect_equal(grid$transpose(), list(list(x = 0), list(x = 1), list(x = 3), list(x = 10)))
+
+})
